@@ -4,40 +4,45 @@ LiveTest - Like WebTest, but on a live site.
 Setup an app to test against with just a hostname:
 
 >>> import livetest
->>> app = livetest.TestApp('www.google.com')
+>>> app = livetest.TestApp('pypi.python.org')
 
 Make requests just like WebTest:
 
->>> resp = app.get('/')
+>>> resp = app.get('/pypi')
 
 Grab forms:
 
->>> resp.forms # doctest: +ELLIPSIS
-{0: <webtest.Form object at 0x...>}
+>>> resp.forms # doctest: +ELLIPSIS +NORMALIZE_WHITESPACE
+{0: <webtest.Form object at 0x...>,
+ 1: <webtest.Form object at 0x...>,
+ u'searchform': <webtest.Form object at 0x...>}
 >>> form = resp.forms[0]
->>> form.fields # doctest: +ELLIPSIS
-{'btnI': [<webtest.Submit object at 0x...>], 'btnG': [<webtest.Submit object at 0x...>], 'q': [<webtest.Text object at 0x...>], 'source': [<webtest.Hidden object at 0x...>], 'hl': [<webtest.Hidden object at 0x...>], 'ie': [<webtest.Hidden object at 0x...>]}
+>>> form.fields # doctest: +ELLIPSIS +NORMALIZE_WHITESPACE
+{u'term': [<webtest.Text object at 0x...>],
+ u':action': [<webtest.Hidden object at 0x...>],
+ u'submit': [<webtest.Submit object at 0x...>]}
 
 Submit forms:
 
->>> form['q'] = 'python testing'
+>>> form['term'] = 'python testing'
 >>> resp = form.submit()
 
 Test stuff in the response:
 
->>> resp.mustcontain('Agile', 'unittest', 'PyUnit')
+>>> resp.mustcontain('livetest', 'Index', 'Package')
 >>> resp.status
 '200 OK'
 
 """
 
 __author__ = 'storborg@mit.edu'
+__version__ = '0.5'
 
 import sys
 import webtest
 import httplib
 import urlparse
-from webtest import BaseCookie, CookieError
+from Cookie import BaseCookie, CookieError
 
 conn_classes = {'http': httplib.HTTPConnection,
                 'https': httplib.HTTPSConnection}
@@ -50,8 +55,9 @@ class TestApp(webtest.TestApp):
         else:
             raise ValueError("Scheme '%s' is not supported." % scheme)
 
-    def __init__(self, host, scheme='http'):
+    def __init__(self, host, scheme='http', relative_to=None):
         self.host = host
+        self.relative_to = relative_to
         self.conn = {}
         self._load_conn(scheme)
         self.extra_environ = {}
